@@ -1,5 +1,4 @@
-#ifndef FILEPREVIEWER_H
-#define FILEPREVIEWER_H
+#pragma once
 
 #include <QObject>
 
@@ -8,8 +7,4 @@ class FilePreviewer : public QObject
     Q_OBJECT
 public:
     explicit FilePreviewer(QObject *parent = nullptr);
-
-signals:
 };
-
-#endif // FILEPREVIEWER_H
