@@ -52,8 +52,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    if (!MAUIAndroid::checkRunTimePermissions({"android.permission.WRITE_EXTERNAL_STORAGE"}))
-        return -1;
 #else
     QApplication app(argc, argv);
 #endif
@@ -108,6 +106,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
             paths << QUrl::fromUserInput(path).toString();
     }
 
+#ifdef Q_OS_ANDROID
+        if (!MAUIAndroid::checkRunTimePermissions({"android.permission.MANAGE_EXTERNAL_STORAGE",
+                                                   "android.permission.WRITE_EXTERNAL_STORAGE"}))
+            qWarning() << "Failed to get WRITE and READ permissions";
+
+#endif
+
 #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
 
     if(parser.isSet(newWindowOption))
